% Calculate Seed-based task co-activation maps, seed from DN, dATN
% author Meiling Li, April, 2017

clear,clc
%% add workbench
addpath(genpath ('/zfs/musc/Xiaoxuan/Software/workbench'));
addpath(genpath('/zfs/musc/Xiaoxuan/Scripts/CIFTIMatlabReaderWriter_Xpeng'));

InPath = '/zfs/musc/Meiling/HCP/TaskActivation';
OutPath = '/zfs/musc/Meiling/HCP/SeedFC/';
mkdir([OutPath '/DMNFC/TASK']);
mkdir([OutPath '/dATNFC/TASK']);

SIDs = textread('/zfs/musc/Meiling/HCP/Lists/HCP_680.txt','%s');

% LOAD ROIs
[cifti,BM] = open_wbfile('/zfs/musc/Xiaoxuan/Scripts/CIFTIMatlabReaderWriter_Xpeng/example.dtseries.nii');
DataIndex = [BM{1}.DataIndices(:); BM{2}.DataIndices(:)];
SurfIndex = [BM{1}.SurfaceIndices(:);32492+BM{2}.SurfaceIndices(:)];

cifti_template = open_wbfile('/zfs/musc/Meiling/HCP/Seeds/DMN/DMNROIs.32k.dscalar.nii');
ROIs_dn = cifti_template.cdata;
ROINum_dn = unique(ROIs_dn);
ROINum_dn(ROINum_dn==0) = [];

%% dATN
cifti_template = open_wbfile('/zfs/musc/Meiling/HCP/Seeds/dATN/dATNROIs.32k.dscalar.nii');
ROIs_atn = cifti_template.cdata;
ROINum_atn = unique(ROIs_atn);
ROINum_atn(ROINum_atn==0) = [];


ConnecMap_dn = zeros(59412,length(ROINum_dn));
ConnecMap_atn = zeros(59412,length(ROINum_atn));
mkdir([OutPath '/TASK']);

for s = 1:length(SIDs)
    s
    sub = SIDs{s};
    % Extract the signal to compute ROI-ROI functional connectivity
    load([InPath '/' sub '/Concanated_47BetaMaps_nozscore.mat']);
    BgSig = BetaMaps'; % 47*59412
    
    ConnecMap_dn_s = zeros(59412,length(ROINum_dn));
    ConnecMap_atn_s = zeros(59412,length(ROINum_atn));
    
    for i = 1:length(ROINum_dn)
        ROIIndex = find(ROIs_dn==ROINum_dn(i));
        ROIsig = nanmean(BgSig(:,ROIIndex),2);
        ConnecMap_dn_s(:,i) = atanh(corr(BgSig,ROIsig));
    end
    ConnecMap_dn = ConnecMap_dn+ConnecMap_dn_s;
    
    
    for i = 1:length(ROINum_atn)
        ROIIndex = find(ROIs_atn==ROINum_atn(i));
        ROIsig = nanmean(BgSig(:,ROIIndex),2);
        ConnecMap_atn_s(:,i) = atanh(corr(BgSig,ROIsig));
    end
    ConnecMap_atn = ConnecMap_atn+ConnecMap_atn_s;
    save([OutPath '/dATNFC/TASK/SeedFC_' sub '.mat'],'ConnecMap_atn_s');
    save([OutPath '/DMNFC/TASK/SeedFC_' sub '.mat'],'ConnecMap_dn_s');

   load([OutPath '/DMNFC/TASK/SeedFC_' sub '.mat']);
   ConnecMap_dn = ConnecMap_dn+ConnecMap_dn_s;

end

% % save the average map
ConnecMap_dn = ConnecMap_dn./s;
PCCMap_z = ConnecMap_dn(:,1);

ConnecMap_dn = tanh(ConnecMap_dn);
PCCMap_r = ConnecMap_dn(:,1);


for i = 1:length(ROINum_dn)
    cifti_template.cdata = ConnecMap_dn(:,i);
    ciftisave(cifti_template,[OutPath '/DMNFC/TASK/Average_ConnectMap_Seed' num2str(i) '.dscalar.nii']);
end


ConnecMap_atn = ConnecMap_atn./s;
ConnecMap_atn = tanh(ConnecMap_atn);
for i = 1:length(ROINum_atn)
    cifti_template.cdata = ConnecMap_atn(:,i);
    ciftisave(cifti_template,[OutPath '/dATNFC/TASK/Average_ConnectMap_Seed' num2str(i) '.dscalar.nii']);
end
